pub trait BodyInner { }Expand description
A marker trait to represent the data that can be included into SuccessBody and ErrorBody.
pub trait BodyInner { }A marker trait to represent the data that can be included into SuccessBody and ErrorBody.