pub struct ReferenceUnlockDto {
pub kind: u8,
pub index: u16,
}Expand description
References a previous unlock block in order to substitute the duplication of the same unlock block data for inputs which unlock through the same data.
Fields
kind: u8index: u16Trait Implementations
Sourceimpl Clone for ReferenceUnlockDto
impl Clone for ReferenceUnlockDto
Sourcefn clone(&self) -> ReferenceUnlockDto
fn clone(&self) -> ReferenceUnlockDto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReferenceUnlockDto
impl Debug for ReferenceUnlockDto
Sourceimpl<'de> Deserialize<'de> for ReferenceUnlockDto
impl<'de> Deserialize<'de> for ReferenceUnlockDto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more