Module responses

Module responses 

Structs

AddPeerResponse
Response of POST /api/v1/peers. Returns information about the added peer.
BalanceAddressResponse
Response of GET /api/v1/addresses/{address}. Returns information about an address.
InfoResponse
Response of GET /api/v1/info. Returns general information about the node.
MessageChildrenResponse
Response of GET /api/v1/messages/{message_id}/children. Returns all children of a specific message.
MessageMetadataResponse
Response of GET /api/v1/messages/{message_id}/metadata. Returns the metadata of a message.
MessageResponse
Response of GET /api/v1/messages/{message_id}. Returns a specific message.
MessagesFindResponse
Response of GET /api/v1/messages?index={INDEX}. Returns all messages ids that match a given indexation key.
MilestoneResponse
Response of GET /api/v1/milestone/{milestone_index}. Returns information about a milestone.
OutputResponse
Response of GET /api/v1/outputs/{output_id}. Returns all information about a specific output.
OutputsAddressResponse
Response of GET /api/v1/addresses/{address}/outputs. Returns the outputs of an address.
PeerResponse
Response of GET /api/v1/peer/{peer_id}. Returns information about a specific peer of the node.
PeersResponse
Response of GET /api/v1/peers. Returns information about all peers of the node.
ReceiptsResponse
Response of:
SubmitMessageResponse
Response of POST /api/v1/messages. Returns the message identifier of the submitted message.
TipsResponse
Response of GET /api/v1/tips. Returns non-lazy tips.
TreasuryResponse
Response of GET /api/v1/treasury. Returns all information about the treasury.
UtxoChangesResponse
Response of GET /api/v1/milestone/{milestone_index}/utxo-changes. Returns all UTXO changes that happened at a specific milestone.
WhiteFlagResponse
Response of GET /api/plugins/debug/whiteflag. Returns the computed merkle tree hash for the given white flag traversal.